Examples
================

Here are some examples of what **autopew** can do and how you can do it. Before
using these examples, please visit the installation and getting started pages.

.. seealso::

  `Installation <../installation.html>`__ ,
  `Getting Started <gettingstarted.html>`__

Workflows
-----------------

This set of pages walks you through how to use **autopew** for each use case.

.. toctree::
   :glob:
   :maxdepth: 1

   workflows/*
